[![Build Status](https://travis-ci.org/vfxGer/pretty-numbers.svg?branch=master)](https://travis-ci.org/vfxGer/pretty-numbers)
[![codecov.io](https://codecov.io/gh/vfxGer/pretty-numbers/coverage.svg?branch=master)](https://codecov.io/gh/vfxGer/pretty-numbers)
[![Code Climate](https://codeclimate.com/github/vfxGer/pretty-numbers/badges/gpa.svg)](https://codeclimate.com/github/vfxGer/pretty-numbers)
pretty-numbers
==============
